import SignUpForm from "@/components/auth/signup-form";
import { auth } from "@/lib/auth";
import prisma from "@/lib/db";
import { headers } from "next/headers";
import Image from "next/image";
import { redirect } from "next/navigation";
import React from "react";

export default async function SignupPage({
	searchParams,
}: {
	searchParams: Promise<{ phone_number: string }>;
}) {
	const session = await auth.api.getSession({
		headers: await headers(),
	});
	if (session) {
		return redirect("/devices");
	}

	const phone_number = (await searchParams).phone_number;
	if (!phone_number) {
		return redirect("/login");
	}
	const atolls = await prisma.atoll.findMany({
		include: {
			islands: true,
		},
	});

	return (
		<div className="bg-gray-100 dark:bg-black w-full h-screen flex items-center justify-center font-sans">
			<div className="flex flex-col items-center justify-center w-full h-full ">
				<Image
					priority
					alt="Sar Link Logo"
					src="/logo.png"
					width={100}
					height={100}
				/>
				<div className="mt-4 flex flex-col items-center justify-center">
					<h4 className="font-bold text-xl text-gray-600">SAR Link Portal</h4>
					<p className="text-gray-500">
						Pay for your devices and track your bills.
					</p>
				</div>
				<SignUpForm atolls={atolls} />
			</div>
		</div>
	);
}
