'use client'
import { Button } from "@/components/ui/button"
import {
  Popover,
  PopoverContent,
  PopoverTrigger,
} from "@/components/ui/popover"
import { authClient } from "@/lib/auth-client";
import { Loader2, User as UserIcon } from "lucide-react"
import { useRouter } from "next/navigation"
import { useState } from "react"

export function AccountPopover() {
  const session = authClient.useSession();
  const [loading, setLoading] = useState(false)
  const router = useRouter()

  if (session.isPending) {
    <Button variant={"outline"} disabled>
      <Loader2 className="animate-spin" />
    </Button>
  }
  return (

    <Popover>
      <PopoverTrigger asChild>
        <Button className="w-fit px-2" variant="outline">
          <UserIcon />
        </Button>
      </PopoverTrigger>
      <PopoverContent className="w-fit">
        <div className="grid gap-4">
          <div className="space-y-2">
            <h4 className="font-medium leading-none">{session.data?.user?.name}</h4>
            <p className="text-sm text-muted-foreground">
              {session.data?.user?.phoneNumber}
            </p>
          </div>
          <Button disabled={loading} onClick={async () => {
            setLoading(true)
            await authClient.signOut({
              fetchOptions: {
                onSuccess: () => {
                  router.push("/login"); // redirect to login page
                },
              },
            })
            setLoading(false)
          }}>
            {loading ? <Loader2 className="animate-spin" /> : "Logout"}
          </Button>
        </div>
      </PopoverContent>
    </Popover>
  )
}
