import { DeviceCartDrawer } from "@/components/device-cart";
import { Wallet } from "@/components/wallet";

import { ModeToggle } from "@/components/theme-toggle";
import { AppSidebar } from "@/components/ui/app-sidebar";

import { Separator } from "@/components/ui/separator";
import {
	SidebarInset,
	SidebarProvider,
	SidebarTrigger,
} from "@/components/ui/sidebar";
import { auth } from "@/lib/auth";
import prisma from "@/lib/db";
import { headers } from "next/headers";
import { AccountPopover } from "./account-popver";

export async function ApplicationLayout({
	children,
}: { children: React.ReactNode }) {
	const session = await auth.api.getSession({
		headers: await headers()
	});
	const billFormula = await prisma.billFormula.findFirst();
	const user = await prisma.user.findFirst({
		where: {
			id: session?.user?.id,
		},
	});
	return (
		<SidebarProvider>
			<AppSidebar role={session?.user?.role || "USER"} />
			<DeviceCartDrawer billFormula={billFormula || null} />
			<SidebarInset>
				<header className="flex justify-between sticky top-0 bg-background h-16 shrink-0 items-center gap-2 border-b px-4 z-10">
					<div className="flex items-center gap-2 ">
						<SidebarTrigger className="-ml-1" />
						<Separator orientation="vertical" className="mr-2 h-4" />
					</div>

					<div className="flex items-center gap-2">
						<Wallet walletBalance={user?.walletBalance || 0} />
						<ModeToggle />
						<AccountPopover />
					</div>
				</header>
				<div className="p-4">{children}</div>
			</SidebarInset>
		</SidebarProvider>
	);
}
